@@ -1,5 +1,5 @@
 # -*- python -*-
-# Copyright (C) 2009-2017 Free Software Foundation, Inc.
+# Copyright (C) 2009-2018 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/ramips_mt7621/build/staging_dir/toolchain-mipsel_24kc_gcc-7.3.0_musl/share/gcc-7.3.0/python'
-libdir = '/builder/ramips_mt7621/build/staging_dir/toolchain-mipsel_24kc_gcc-7.3.0_musl/mipsel-openwrt-linux-musl/lib'
+pythondir = '/builder/shared-workdir/build/staging_dir/toolchain-mipsel_24kc_gcc-8.4.0_musl/share/gcc-8.4.0/python'
+libdir = '/builder/shared-workdir/build/staging_dir/toolchain-mipsel_24kc_gcc-8.4.0_musl/mipsel-openwrt-linux-musl/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
